function [m,Fv,F,C]=comb_coars_disj(mm,FF,K,version);

% Copyright Thierry Denoeux 
% April 4, 2002
%

% Approximate disjunctive combination of several basic belief assignments (bba's),
% using the coarsening approximation method
%
% [m,Fv,F,C]=comb_coars_disj(mm,FF,K,version);
%
% Input:
% mm = cell array containing the belief masses of the bba's
%      mm{k} is the vector (n,1) of belief masses for the n focal elements of the k-th bba
% FF = cell array containing the focal elements of the bba's
%      FF{k} is a (n,c) matrix of focal elements for the k-th bba
% Let F=FF{k}. Then:
% F(i,j)=1 if focal element Fi contains element j
%       =0 otherwise
% K = desired size of frame
% version = 'in' for inner approximation, 'out' for outer approximation
%
% Output
% m = (n,1) vector of belief masses for the combined bba 
% Fv = (n,c) matrix of focal elements for the combined bba, in the
%      initial frame
% F =  (n,K) matrix of focal elements for the combined bba, in the
%      coarsened frame
% C = vector (c,1). C(i) is the class of singleton i in the partition

% Uses:
% - appcoars_m (this toolbox), and
% - Philippe Smets's TBM toolbox

[mm,FFc,FFa,C,N,N0]=appcoars_m(mm,FF,K,version);

nbbm=length(mm);
b1=mtob(mtobbm(mm{1},FFc{1}));

for i=2:nbbm,
   b=mtob(mtobbm(mm{i},FFc{i}));
   b1=b1.*b;
end;

bbm=btom(b1);
[m,F]=bbmtom(bbm);  
c=length(C);
Fv=zeros(size(F,1),c);
for i=1:c,
    Fv(:,i)=F(:,C(i));
end;


